.. _examples-stimuli:

Stimuli
=======

The :py:mod:`~pulse2percept.stimuli` module provides a number of common
electrical stimulus types, such as 
:py:class:`~pulse2percept.stimuli.BiphasicPulseTrain`,
which can be assigned to electrodes of a 
:py:class:`~pulse2percept.implants.ProsthesisSystem` object.

Stimuli can also be created from images 
(:py:class:`~pulse2percept.stimuli.ImageStimulus`) and videos
(:py:class:`~pulse2percept.stimuli.VideoStimulus`).